@@ -1,16 +1,17 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2022 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2022-2024 -- leonerd@leonerd.org.uk
 
-package Syntax::Operator::Elem 0.08;
+package Syntax::Operator::Elem 0.09;
 
 use v5.14;
 use warnings;
 
 use Carp;
 
-use meta;
+use meta 0.003_002;
+no warnings 'meta::experimental';
 
 =encoding UTF-8
 
